==> app_02_08_2024.zip: resources/views/admin/layouts/menu.blade.php <==
        <!-- Menu -->

        <aside id="layout-menu" class="layout-menu menu-vertical menu bg-menu-theme">
          <div class="app-brand demo">
            <a href="{{url('admin/dashboard')}}" class="app-brand-link">
              <span class="app-brand-logo demo">
                <svg width="32" height="22" viewBox="0 0 32 22" fill="none" xmlns="http://www.w3.org/2000/svg">
                  <path
                    fill-rule="evenodd"
                    clip-rule="evenodd"
                    d="M0.00172773 0V6.85398C0.00172773 6.85398 -0.133178 9.01207 1.98092 10.8388L13.6912 21.9964L19.7809 21.9181L18.8042 9.88248L16.4951 7.17289L9.23799 0H0.00172773Z"
                    fill="#7367F0" />
                  <path
                    opacity="0.06"
                    fill-rule="evenodd"
                    clip-rule="evenodd"
                    d="M7.69824 16.4364L12.5199 3.23696L16.5541 7.25596L7.69824 16.4364Z"
                    fill="#161616" />
                  <path
                    opacity="0.06"
                    fill-rule="evenodd"
                    clip-rule="evenodd"
                    d="M8.07751 15.9175L13.9419 4.63989L16.5849 7.28475L8.07751 15.9175Z"
                    fill="#161616" />
                  <path
                    fill-rule="evenodd"
                    clip-rule="evenodd"
                    d="M7.77295 16.3566L23.6563 0H32V6.88383C32 6.88383 31.8262 9.17836 30.6591 10.4057L19.7824 22H13.6938L7.77295 16.3566Z"
                    fill="#7367F0" />
                </svg>
              </span>
              <span class="app-brand-text demo menu-text fw-bold">{{__('lang.admin')}}</span>
            </a>

            <a href="javascript:void(0);" class="layout-menu-toggle menu-link text-large ms-auto">
              <i class="ti menu-toggle-icon d-none d-xl-block ti-sm align-middle"></i>
              <i class="ti ti-x d-block d-xl-none ti-sm align-middle"></i>
            </a>
          </div>

          <div class="menu-inner-shadow"></div>

          <ul class="menu-inner py-1">
            <!-- Dashboards -->
            <li class="menu-item active">
              <a href="{{url('admin/dashboard')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-smart-home"></i>
                <div data-i18n="{{__('lang.admin_dashboard')}}">{{__('lang.admin_dashboard')}}</div>
              </a>
            </li>

            <!-- Management-->
            <li class="menu-header small text-uppercase">
              <span class="menu-header-text" data-i18n="{{__('lang.admin_category_management')}}">{{__('lang.admin_category_management')}}</span>
            </li>

            <!-- Category -->
            <li class="menu-item" style="display:none;">
              <a href="javascript:void(0);" class="menu-link menu-toggle">
                <i class="menu-icon tf-icons ti ti-id"></i>
                <div data-i18n="{{__('lang.admin_category')}}">{{__('lang.admin_category')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">3</div>
              </a>
              <ul class="menu-sub">
                  <!-- Category -->
                  <li class="menu-item">
                    <a href="{{url('admin/category')}}" class="menu-link">
                      <div data-i18n="{{__('lang.admin_category_list')}}">{{__('lang.admin_category_list')}}</div>
                    </a>
                  </li>

                  <!-- Subcategory -->
                  <li class="menu-item">
                    <a href="{{url('admin/subcategory')}}" class="menu-link">
                      <div data-i18n="{{__('lang.admin_subcategory_list')}}">{{__('lang.admin_subcategory_list')}}</div>
                    </a>
                  </li>

                  <!-- Category Bulk Export -->
                  <li class="menu-item">
                    <a href="{{url('admin/category-bulk')}}" class="menu-link">
                      <div data-i18n="{{__('lang.admin_category_import_export')}}">{{__('lang.admin_category_import_export')}}</div>
                    </a>
                  </li>
              </ul>
            </li>

            <!-- category -->
            <li class="menu-item" style="display:none;">
              <a href="{{url('admin/category')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-id"></i>
                <div data-i18n="{{__('lang.admin_category')}}">{{__('lang.admin_category')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Category::count()}}</div>
              </a>
            </li>
            
            <!-- Slider -->
            <li class="menu-item">
              <a href="{{url('admin/slider')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-id"></i>
                <div data-i18n="{{__('lang.admin_slider')}}">{{__('lang.admin_slider')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Slider::count()}}</div>
              </a>
            </li>

            <!-- Aminity -->
            <li class="menu-item">
              <a href="{{url('admin/aminity')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-clock"></i>
                <div data-i18n="{{__('lang.admin_aminity')}}">{{__('lang.admin_aminity')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Aminity::count()}}</div>
              </a>
            </li>

            <!-- Feature -->
            <li class="menu-item" style="display:none;">
              <a href="{{url('admin/feature')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-smart-home"></i>
                <div data-i18n="{{__('lang.admin_feature')}}">{{__('lang.admin_feature')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Feature::count()}}</div>
              </a>
            </li>
            
            <!-- Feature -->
            <li class="menu-item">
              <a href="{{url('admin/offer')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-smart-home"></i>
                <div data-i18n="{{__('lang.admin_offer')}}">{{__('lang.admin_offer')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Offer::count()}}</div>
              </a>
            </li>
            
            <!-- Feature -->
            <li class="menu-item">
              <a href="{{url('admin/rules')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-link"></i>
                <div data-i18n="{{__('lang.admin_rules')}}">{{__('lang.admin_rules')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Rules::count()}}</div>
              </a>
            </li>

            <!-- Destination -->
            <li class="menu-item">
              <a href="{{url('admin/destination')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-components"></i>
                <div data-i18n="{{__('lang.admin_destination')}}">{{__('lang.admin_destination')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Destination::count()}}</div>
              </a>
            </li>
            
            <!-- Package -->
            <!--<li class="menu-item">-->
            <!--  <a href="{{url('admin/package')}}" class="menu-link">-->
            <!--    <i class="menu-icon tf-icons ti ti-wallet"></i>-->
            <!--    <div data-i18n="{{__('lang.admin_package')}}">{{__('lang.admin_package')}}</div>-->
            <!--    <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Package::count()}}</div>-->
            <!--  </a>-->
            <!--</li>-->

            <!-- Hotel -->
            <li class="menu-item">
              <a href="{{url('admin/hotel')}}" class="menu-link">
                <i class="menu-icon ti ti-circle ti-burst"></i>
                <div data-i18n="{{__('lang.admin_house')}}">{{__('lang.admin_house')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Hotel::count()}}</div>
              </a>
            </li>
            
            <!--Promotions Management-->
            <li class="menu-header small text-uppercase">
              <span class="menu-header-text" data-i18n="{{__('lang.admin_promotions_management')}}">{{__('lang.admin_promotions_management')}}</span>
            </li>

            <!-- Coupon -->
            <li class="menu-item">
              <a href="{{url('admin/coupon')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-tag"></i>
                <div data-i18n="{{__('lang.admin_coupon_list')}}">{{__('lang.admin_coupon_list')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Coupon::count()}}</div>
              </a>
            </li>

             <!--User Management-->
            <li class="menu-header small text-uppercase">
              <span class="menu-header-text" data-i18n="{{__('lang.admin_customer_management')}}">{{__('lang.admin_customer_management')}}</span>
            </li>

            <!-- Customer -->
            <li class="menu-item">
              <a href="{{url('admin/customer')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-users"></i>
                <div data-i18n="{{__('lang.admin_customer_list')}}">{{__('lang.admin_customer_list')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\User::where('type','user')->where('name','!=','')->count()}}</div>
              </a>
            </li>
            
            <!-- Customer -->
            <li class="menu-item">
              <a href="{{url('admin/bookings')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-wallet"></i>
                <div data-i18n="{{__('lang.admin_bookings_list')}}">{{__('lang.admin_bookings_list')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Booking::count()}}</div>
              </a>
            </li>
            
            <!--User Management-->
            <li class="menu-header small text-uppercase">
              <span class="menu-header-text" data-i18n="{{__('lang.admin_vendor_management')}}">{{__('lang.admin_vendor_management')}}</span>
            </li>
            
            
            <!-- Vendor -->
            <li class="menu-item">
              <a href="{{url('admin/vendor')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-user"></i>
                <div data-i18n="{{__('lang.admin_vendor_list')}}">{{__('lang.admin_vendor_list')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Vendor::count()}}</div>
              </a>
            </li>
            

            <!-- Vendor  Hotel -->
            <li class="menu-item">
              <a href="{{url('admin/vendors-hotel')}}" class="menu-link">
                <i class="menu-icon ti ti-circle ti-burst"></i>
                <div data-i18n="{{__('lang.admin_vendor_hotel')}}">{{__('lang.admin_vendor_hotel')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Hotel::where('add_type','Vendor')->count()}}</div>
              </a>
            </li>



          </ul>
        </aside>
        <!-- / Menu -->

==> app_04_12_2024.zip: resources/views/admin/layouts/menu.blade.php <==
        <!-- Menu -->

        <aside id="layout-menu" class="layout-menu menu-vertical menu bg-menu-theme">
          <div class="app-brand demo">
            <a href="{{url('admin/dashboard')}}" class="app-brand-link">
              <span class="app-brand-logo demo">
                <svg width="32" height="22" viewBox="0 0 32 22" fill="none" xmlns="http://www.w3.org/2000/svg">
                  <path
                    fill-rule="evenodd"
                    clip-rule="evenodd"
                    d="M0.00172773 0V6.85398C0.00172773 6.85398 -0.133178 9.01207 1.98092 10.8388L13.6912 21.9964L19.7809 21.9181L18.8042 9.88248L16.4951 7.17289L9.23799 0H0.00172773Z"
                    fill="#7367F0" />
                  <path
                    opacity="0.06"
                    fill-rule="evenodd"
                    clip-rule="evenodd"
                    d="M7.69824 16.4364L12.5199 3.23696L16.5541 7.25596L7.69824 16.4364Z"
                    fill="#161616" />
                  <path
                    opacity="0.06"
                    fill-rule="evenodd"
                    clip-rule="evenodd"
                    d="M8.07751 15.9175L13.9419 4.63989L16.5849 7.28475L8.07751 15.9175Z"
                    fill="#161616" />
                  <path
                    fill-rule="evenodd"
                    clip-rule="evenodd"
                    d="M7.77295 16.3566L23.6563 0H32V6.88383C32 6.88383 31.8262 9.17836 30.6591 10.4057L19.7824 22H13.6938L7.77295 16.3566Z"
                    fill="#7367F0" />
                </svg>
              </span>
              <span class="app-brand-text demo menu-text fw-bold">{{__('lang.admin')}}</span>
            </a>

            <a href="javascript:void(0);" class="layout-menu-toggle menu-link text-large ms-auto">
              <i class="ti menu-toggle-icon d-none d-xl-block ti-sm align-middle"></i>
              <i class="ti ti-x d-block d-xl-none ti-sm align-middle"></i>
            </a>
          </div>

          <div class="menu-inner-shadow"></div>

          <ul class="menu-inner py-1">
            <!-- Dashboards -->
            <li class="menu-item active">
              <a href="{{url('admin/dashboard')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-smart-home"></i>
                <div data-i18n="{{__('lang.admin_dashboard')}}">{{__('lang.admin_dashboard')}}</div>
              </a>
            </li>

            <!-- Management-->
            <li class="menu-header small text-uppercase">
              <span class="menu-header-text" data-i18n="{{__('lang.admin_category_management')}}">{{__('lang.admin_category_management')}}</span>
            </li>

            <!-- Category -->
            <li class="menu-item" style="display:none;">
              <a href="javascript:void(0);" class="menu-link menu-toggle">
                <i class="menu-icon tf-icons ti ti-id"></i>
                <div data-i18n="{{__('lang.admin_category')}}">{{__('lang.admin_category')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">3</div>
              </a>
              <ul class="menu-sub">
                  <!-- Category -->
                  <li class="menu-item">
                    <a href="{{url('admin/category')}}" class="menu-link">
                      <div data-i18n="{{__('lang.admin_category_list')}}">{{__('lang.admin_category_list')}}</div>
                    </a>
                  </li>

                  <!-- Subcategory -->
                  <li class="menu-item">
                    <a href="{{url('admin/subcategory')}}" class="menu-link">
                      <div data-i18n="{{__('lang.admin_subcategory_list')}}">{{__('lang.admin_subcategory_list')}}</div>
                    </a>
                  </li>

                  <!-- Category Bulk Export -->
                  <li class="menu-item">
                    <a href="{{url('admin/category-bulk')}}" class="menu-link">
                      <div data-i18n="{{__('lang.admin_category_import_export')}}">{{__('lang.admin_category_import_export')}}</div>
                    </a>
                  </li>
              </ul>
            </li>

            <!-- category -->
            <li class="menu-item" style="display:none;">
              <a href="{{url('admin/category')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-id"></i>
                <div data-i18n="{{__('lang.admin_category')}}">{{__('lang.admin_category')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Category::count()}}</div>
              </a>
            </li>
            
            <!-- Slider -->
            <li class="menu-item">
              <a href="{{url('admin/slider')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-id"></i>
                <div data-i18n="{{__('lang.admin_slider')}}">{{__('lang.admin_slider')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Slider::count()}}</div>
              </a>
            </li>

            <!-- Aminity -->
            <li class="menu-item">
              <a href="{{url('admin/aminity')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-clock"></i>
                <div data-i18n="{{__('lang.admin_aminity')}}">{{__('lang.admin_aminity')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Aminity::count()}}</div>
              </a>
            </li>

            <!-- Feature -->
            <li class="menu-item" style="display:none;">
              <a href="{{url('admin/feature')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-smart-home"></i>
                <div data-i18n="{{__('lang.admin_feature')}}">{{__('lang.admin_feature')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Feature::count()}}</div>
              </a>
            </li>
            
            <!-- Feature -->
            <li class="menu-item">
              <a href="{{url('admin/offer')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-smart-home"></i>
                <div data-i18n="{{__('lang.admin_offer')}}">{{__('lang.admin_offer')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Offer::count()}}</div>
              </a>
            </li>
            
            <!-- Feature -->
            <li class="menu-item">
              <a href="{{url('admin/rules')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-link"></i>
                <div data-i18n="{{__('lang.admin_rules')}}">{{__('lang.admin_rules')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Rules::count()}}</div>
              </a>
            </li>

            <!-- Destination -->
            <li class="menu-item">
              <a href="{{url('admin/destination')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-components"></i>
                <div data-i18n="{{__('lang.admin_destination')}}">{{__('lang.admin_destination')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Destination::count()}}</div>
              </a>
            </li>
            
            <!-- Package -->
            <!--<li class="menu-item">-->
            <!--  <a href="{{url('admin/package')}}" class="menu-link">-->
            <!--    <i class="menu-icon tf-icons ti ti-wallet"></i>-->
            <!--    <div data-i18n="{{__('lang.admin_package')}}">{{__('lang.admin_package')}}</div>-->
            <!--    <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Package::count()}}</div>-->
            <!--  </a>-->
            <!--</li>-->

            <!-- Hotel -->
            <li class="menu-item">
              <a href="{{url('admin/hotel')}}" class="menu-link">
                <i class="menu-icon ti ti-circle ti-burst"></i>
                <div data-i18n="{{__('lang.admin_house')}}">{{__('lang.admin_house')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Hotel::count()}}</div>
              </a>
            </li>
            
            <!--Video Content -->
             <li class="menu-item">
              <a href="{{ url('admin/video-content') }}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-components"></i>
                <div data-i18n="Video Content">Video Content</div>
              </a>
            </li>
            
             <!--Block Date -->
            <li class="menu-item">
              <a href="{{ url('admin/blockdate') }}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-components"></i>
                <div data-i18n="Block Date">Block Date</div>
              </a>
            </li>
            
            
            <!--Promotions Management-->
            <li class="menu-header small text-uppercase">
              <span class="menu-header-text" data-i18n="{{__('lang.admin_promotions_management')}}">{{__('lang.admin_promotions_management')}}</span>
            </li>

            <!-- Coupon -->
            <li class="menu-item">
              <a href="{{url('admin/coupon')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-tag"></i>
                <div data-i18n="{{__('lang.admin_coupon_list')}}">{{__('lang.admin_coupon_list')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Coupon::count()}}</div>
              </a>
            </li>
             <!--User Management-->
            <li class="menu-header small text-uppercase">
              <span class="menu-header-text" data-i18n="{{__('lang.admin_customer_management')}}">{{__('lang.admin_customer_management')}}</span>
            </li>

            <!-- Customer -->
            <li class="menu-item">
              <a href="{{url('admin/customer')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-users"></i>
                <div data-i18n="{{__('lang.admin_customer_list')}}">{{__('lang.admin_customer_list')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\User::where('type','user')->where('name','!=','')->count()}}</div>
              </a>
            </li>
            
            <!-- Customer -->
            <li class="menu-item">
              <a href="{{url('admin/bookings')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-wallet"></i>
                <div data-i18n="{{__('lang.admin_bookings_list')}}">{{__('lang.admin_bookings_list')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Booking::count()}}</div>
              </a>
            </li>
            
            <!--User Management-->
            <li class="menu-header small text-uppercase">
              <span class="menu-header-text" data-i18n="{{__('lang.admin_vendor_management')}}">{{__('lang.admin_vendor_management')}}</span>
            </li>
            
            
            <!-- Vendor -->
            <li class="menu-item">
              <a href="{{url('admin/vendor')}}" class="menu-link">
                <i class="menu-icon tf-icons ti ti-user"></i>
                <div data-i18n="{{__('lang.admin_vendor_list')}}">{{__('lang.admin_vendor_list')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Vendor::count()}}</div>
              </a>
            </li>
            

            <!-- Vendor  Hotel -->
            <li class="menu-item">
              <a href="{{url('admin/vendors-hotel')}}" class="menu-link">
                <i class="menu-icon ti ti-circle ti-burst"></i>
                <div data-i18n="{{__('lang.admin_vendor_hotel')}}">{{__('lang.admin_vendor_hotel')}}</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\Hotel::where('add_type','Vendor')->count()}}</div>
              </a>
            </li>
            
             <!--Vendor offer -->
            <li class="menu-item">
              <a href="{{url('admin/vendor-offer')}}" class="menu-link">
                <i class="menu-icon tf-icons fas fa-gift"></i>
                <div data-i18n="Offer">Vendor Offer</div>
                <div class="badge bg-primary rounded-pill ms-auto">{{App\Models\VendorOffer::count()}}</div>
              </a>
            </li>



          </ul>
        </aside>
        <!-- / Menu -->
